<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_HK" sourcelanguage="en">
<context>
    <name>ActionShowStashDelegate</name>
    <message>
        <source>Application tray</source>
        <translation>應用托盤</translation>
    </message>
</context>
<context>
    <name>ActionToggleCollapseDelegate</name>
    <message>
        <source>Collapse tray</source>
        <translation>折疊托盤</translation>
    </message>
</context>
<context>
    <name>PanelTrayItem</name>
    <message>
        <source>Quick actions</source>
        <translation>快速設定</translation>
    </message>
</context>
</TS>